@@ -2,7 +2,7 @@ use {
     super::{errors::CacheError, metadata},
     crate::channels::define::ChannelData,
     bytes::BytesMut,
-    flvparser::{define, tag_parser},
+    xflv::{define, demuxer_tag},
 };
 
 pub struct Cache {
@@ -85,12 +85,16 @@ impl Cache {
         self.metadata_timestamp = timestamp;
     }
 
-    pub fn get_metadata(&self) -> ChannelData {
+    pub fn get_metadata(&self) -> Option<ChannelData> {
         let data = self.metadata.get_chunk_body();
-        return ChannelData::MetaData {
-            timestamp: self.metadata_timestamp,
-            data,
-        };
+        if data.len() > 0 {
+            Some(ChannelData::MetaData {
+                timestamp: self.metadata_timestamp,
+                data,
+            })
+        } else {
+            None
+        }
     }
 
     pub fn save_audio_seq(
@@ -98,11 +102,11 @@ impl Cache {
         chunk_body: BytesMut,
         timestamp: u32,
     ) -> Result<(), CacheError> {
-        let mut parser = tag_parser::TagParser::new(chunk_body.clone(), define::TagType::AUDIO);
-        let tag = parser.parse()?;
+        let mut parser = demuxer_tag::AudioTagHeaderDemuxer::new(chunk_body.clone());
+        let tag = parser.parse_tag_header()?;
 
         if tag.sound_format == define::sound_format::AAC
-            && tag.avc_packet_type == define::aac_packet_type::AAC_SEQHDR
+            && tag.aac_packet_type == define::aac_packet_type::AAC_SEQHDR
         {
             self.audio_seq = chunk_body;
             self.audio_timestamp = timestamp;
@@ -111,18 +115,24 @@ impl Cache {
         Ok(())
     }
 
-    pub fn get_audio_seq(&self) -> ChannelData {
-        return ChannelData::Audio {
-            timestamp: self.audio_timestamp,
-            data: self.audio_seq.clone(),
-        };
+    pub fn get_audio_seq(&self) -> Option<ChannelData> {
+        if self.audio_seq.len() > 0 {
+            return Some(ChannelData::Audio {
+                timestamp: self.audio_timestamp,
+                data: self.audio_seq.clone(),
+            });
+        }
+        None
     }
 
-    pub fn get_video_seq(&self) -> ChannelData {
-        return ChannelData::Video {
-            timestamp: self.video_timestamp,
-            data: self.video_seq.clone(),
-        };
+    pub fn get_video_seq(&self) -> Option<ChannelData> {
+        if self.video_seq.len() > 0 {
+            return Some(ChannelData::Video {
+                timestamp: self.video_timestamp,
+                data: self.video_seq.clone(),
+            });
+        }
+        None
     }
 
     pub fn save_video_seq(
@@ -130,8 +140,8 @@ impl Cache {
         chunk_body: BytesMut,
         timestamp: u32,
     ) -> Result<(), CacheError> {
-        let mut parser = tag_parser::TagParser::new(chunk_body.clone(), define::TagType::VIDEO);
-        let tag = parser.parse()?;
+        let mut parser = demuxer_tag::VideoTagHeaderDemuxer::new(chunk_body.clone());
+        let tag = parser.parse_tag_header()?;
 
         if tag.frame_type == define::frame_type::KEY_FRAME
             && tag.avc_packet_type == define::avc_packet_type::AVC_SEQHDR
