@@ -16,8 +16,10 @@ use {
         //cell::RefCell,
         collections::HashMap,
         sync::{Arc, Mutex},
+        //time::Duration,
     },
     tokio::sync::{mpsc, mpsc::UnboundedReceiver, oneshot},
+    //tokio::time::sleep,
 };
 
 /************************************************************************************
@@ -69,7 +71,7 @@ impl Transmiter {
             tokio::select! {
                 data = self.event_consumer.recv() =>{
                     if let Some(val) = data{
-                        print!("receive player event\n");
+
                         match val{
                             TransmitEvent::Subscribe { responder,session_info } => {
 
@@ -80,21 +82,29 @@ impl Transmiter {
 
                                 match session_info.session_sub_type {
                                     SessionSubType::Player=>{
+
                                         let meta_body = self.cache.lock().unwrap().get_metadata();
+                                        if let Some(meta_body_data) = meta_body{
+                                            sender.send(meta_body_data).map_err(|_| ChannelError {
+                                                value: ChannelErrorValue::SendError,
+                                            })?;
+
+                                        }
+
                                         let audio_seq = self.cache.lock().unwrap().get_audio_seq();
+                                        if let Some(audio_seq_data) = audio_seq{
+                                            sender.send(audio_seq_data).map_err(|_| ChannelError {
+                                                value: ChannelErrorValue::SendError,
+                                            })?;
+                                        }
+
                                         let video_seq = self.cache.lock().unwrap().get_video_seq();
-
-                                        sender.send(meta_body).map_err(|_| ChannelError {
-                                            value: ChannelErrorValue::SendError,
-                                        })?;
-                                        sender.send(audio_seq).map_err(|_| ChannelError {
-                                            value: ChannelErrorValue::SendError,
-                                        })?;
-                                        sender.send(video_seq).map_err(|_| ChannelError {
-                                            value: ChannelErrorValue::SendError,
-                                        })?;
-
-                                    }
+                                        if let Some(video_seq_data) = video_seq{
+                                            sender.send(video_seq_data).map_err(|_| ChannelError {
+                                                value: ChannelErrorValue::SendError,
+                                            })?;
+                                        }
+                                     }
                                     SessionSubType::Publisher =>{
 
                                     }
@@ -186,6 +196,7 @@ pub struct ChannelsManager {
     client_event_producer: ClientEventProducer,
     push_enabled: bool,
     pull_enabled: bool,
+    hls_enabled: bool,
 }
 
 impl ChannelsManager {
@@ -200,6 +211,7 @@ impl ChannelsManager {
             client_event_producer: client_producer,
             push_enabled: false,
             pull_enabled: false,
+            hls_enabled: false,
         }
     }
     pub async fn run(&mut self) {
@@ -210,6 +222,10 @@ impl ChannelsManager {
         self.push_enabled = enabled;
     }
 
+    pub fn set_hls_enabled(&mut self, enabled: bool) {
+        self.hls_enabled = enabled;
+    }
+
     pub fn set_pull_enabled(&mut self, enabled: bool) {
         self.pull_enabled = enabled;
     }
@@ -224,6 +240,7 @@ impl ChannelsManager {
 
     pub async fn event_loop(&mut self) {
         while let Some(message) = self.channel_event_consumer.recv().await {
+            log::info!("event_loop receive event: {}", message);
             match message {
                 ChannelEvent::Publish {
                     app_name,
@@ -234,11 +251,11 @@ impl ChannelsManager {
                     match rv {
                         Ok(producer) => {
                             if let Err(_) = responder.send(producer) {
-                                print!("event_loop responder send err\n");
+                                log::error!("event_loop responder send err");
                             }
                         }
                         Err(err) => {
-                            print!("event_loop Publish err: {}\n", err);
+                            log::error!("event_loop Publish err: {}\n", err);
                             continue;
                         }
                     }
@@ -249,7 +266,7 @@ impl ChannelsManager {
                     stream_name,
                 } => {
                     if let Err(err) = self.unpublish(&app_name, &stream_name) {
-                        println!("unpublish err: {}", err);
+                        log::error!("event_loop Unpublish err: {}\n", err);
                     }
                 }
                 ChannelEvent::Subscribe {
@@ -261,7 +278,10 @@ impl ChannelsManager {
                     let rv = self.subscribe(&app_name, &stream_name, session_info).await;
                     match rv {
                         Ok(consumer) => if let Err(_) = responder.send(consumer) {},
-                        Err(_) => continue,
+                        Err(err) => {
+                            log::error!("event_loop Subscribe error: {}", err);
+                            continue;
+                        }
                     }
                 }
                 ChannelEvent::UnSubscribe {
@@ -299,6 +319,7 @@ impl ChannelsManager {
 
                     match receiver.await {
                         Ok(consumer) => {
+                            log::info!("subscribe get consumer successfully, app_name: {}, stream_name: {}",app_name,stream_name);
                             return Ok(consumer);
                         }
                         Err(_) => {
@@ -323,6 +344,12 @@ impl ChannelsManager {
         }
 
         if self.pull_enabled {
+            log::info!(
+                "subscribe: try to pull stream, app_name: {}, stream_name: {}",
+                app_name,
+                stream_name
+            );
+
             let client_event = ClientEvent::Subscribe {
                 app_name: app_name.clone(),
                 stream_name: stream_name.clone(),
@@ -397,15 +424,24 @@ impl ChannelsManager {
             let (data_publisher, data_consumer) = mpsc::unbounded_channel();
 
             let mut transmiter = Transmiter::new(data_consumer, event_consumer);
+
+            let app_name_clone = app_name.clone();
+            let stream_name_clone = stream_name.clone();
+
             tokio::spawn(async move {
                 if let Err(err) = transmiter.run().await {
-                    print!("transmiter error {}\n", err);
+                    log::error!(
+                        "transmiter run error, app_name: {}, stream_name: {}, error: {}",
+                        app_name_clone,
+                        stream_name_clone,
+                        err,
+                    );
                 }
             });
 
             stream_map.insert(stream_name.clone(), event_publisher);
 
-            if self.push_enabled {
+            if self.push_enabled || self.hls_enabled {
                 let client_event = ClientEvent::Publish {
                     app_name: app_name.clone(),
                     stream_name: stream_name.clone(),
@@ -428,7 +464,6 @@ impl ChannelsManager {
     }
 
     fn unpublish(&mut self, app_name: &String, stream_name: &String) -> Result<(), ChannelError> {
-        println!("unpublish begin...{} {}", app_name, stream_name);
         match self.channels.get_mut(app_name) {
             Some(val) => match val.get_mut(stream_name) {
                 Some(producer) => {
@@ -437,7 +472,11 @@ impl ChannelsManager {
                         value: ChannelErrorValue::SendError,
                     })?;
                     val.remove(stream_name);
-                    print!("remove stream name{}\n", stream_name);
+                    log::info!(
+                        "unpublish remove stream, app_name: {},stream_name: {}",
+                        app_name,
+                        stream_name
+                    );
                 }
                 None => {
                     return Err(ChannelError {
