@@ -16,14 +16,14 @@ use {
         messages::define::msg_type_id,
     },
     bytes::BytesMut,
-    networkio::networkio::NetworkIO,
+    bytesio::bytesio::BytesIO,
     std::{sync::Arc, time::Duration},
     tokio::{
         sync::{mpsc, oneshot, Mutex},
         time::sleep,
     },
 };
-
+#[derive(Debug)]
 pub struct SessionInfo {
     pub session_id: u64,
     pub session_sub_type: SessionSubType,
@@ -40,7 +40,7 @@ pub struct Common {
 
 impl Common {
     pub fn new(
-        net_io: Arc<Mutex<NetworkIO>>,
+        net_io: Arc<Mutex<BytesIO>>,
         event_producer: ChannelEventProducer,
         session_type: SessionType,
     ) -> Self {
@@ -136,11 +136,10 @@ impl Common {
             data: data.clone(),
         };
 
-        //print!("receive video data\n");
         match self.data_producer.send(data) {
             Ok(_) => {}
             Err(err) => {
-                print!("send video err {}\n", err);
+                log::error!("send video err: {}", err);
                 return Err(SessionError {
                     value: SessionErrorValue::SendChannelDataErr,
                 });
@@ -163,7 +162,7 @@ impl Common {
         match self.data_producer.send(data) {
             Ok(_) => {}
             Err(err) => {
-                print!("receive audio err {}\n", err);
+                log::error!("receive audio err {}\n", err);
                 return Err(SessionError {
                     value: SessionErrorValue::SendChannelDataErr,
                 });
@@ -208,14 +207,15 @@ impl Common {
         }
     }
 
+    /*Begin to send data to common player or relay pull client*/
     pub async fn subscribe_from_channels(
         &mut self,
         app_name: String,
         stream_name: String,
         session_id: u64,
     ) -> Result<(), SessionError> {
-        print!(
-            "subscribe info............{} {} {}\n",
+        log::info!(
+            "subscribe_from_channels, app_name: {} stream_name: {} session_id: {}\n",
             app_name,
             stream_name.clone(),
             session_id
@@ -275,12 +275,13 @@ impl Common {
             session_info: self.get_session_info(session_id),
         };
         if let Err(err) = self.event_producer.send(subscribe_event) {
-            print!("unsubscribe_from_channels err {}\n", err)
+            log::error!("unsubscribe_from_channels err {}\n", err);
         }
 
         Ok(())
     }
 
+    /*Begin to receive stream data from RTMP push client or RTMP relay push client*/
     pub async fn publish_to_channels(
         &mut self,
         app_name: String,
@@ -305,12 +306,10 @@ impl Common {
 
         match receiver.await {
             Ok(producer) => {
-                //print!("set producer before\n");
                 self.data_producer = producer;
-                //print!("set producer after\n");
             }
             Err(err) => {
-                print!("publish_to_channels err{}\n", err)
+                log::error!("publish_to_channels err{}\n", err);
             }
         }
         Ok(())
@@ -322,20 +321,28 @@ impl Common {
         stream_name: String,
     ) -> Result<(), SessionError> {
         let unpublish_event = ChannelEvent::UnPublish {
-            app_name,
-            stream_name,
+            app_name: app_name.clone(),
+            stream_name: stream_name.clone(),
         };
 
         let rv = self.event_producer.send(unpublish_event);
         match rv {
             Err(_) => {
-                println!("unpublish_to_channels error.");
+                log::error!(
+                    "unpublish_to_channels error.app_name: {}, stream_name: {}",
+                    app_name,
+                    stream_name
+                );
                 return Err(SessionError {
                     value: SessionErrorValue::ChannelEventSendErr,
                 });
             }
             _ => {
-                println!("unpublish_to_channels successfully.")
+                log::info!(
+                    "unpublish_to_channels successfully.app_name: {}, stream_name: {}",
+                    app_name,
+                    stream_name
+                );
             }
         }
         Ok(())
