@@ -15,7 +15,7 @@ use {
             ChunkInfo,
         },
         config,
-        handshake::handshake::{ServerHandshakeState,HandshakeServer},
+        handshake::handshake::{HandshakeServer, ServerHandshakeState},
         messages::{
             define::{msg_type_id, RtmpMessageData},
             parser::MessageParser,
@@ -26,9 +26,9 @@ use {
         user_control_messages::writer::EventMessagesWriter,
     },
     bytes::BytesMut,
-    networkio::{
+    bytesio::{
         bytes_writer::{AsyncBytesWriter, BytesWriter},
-        networkio::NetworkIO,
+        bytesio::BytesIO,
     },
     std::{collections::HashMap, sync::Arc},
     tokio::{net::TcpStream, sync::Mutex},
@@ -47,9 +47,9 @@ pub struct ServerSession {
     app_name: String,
     stream_name: String,
 
-    io: Arc<Mutex<NetworkIO>>,
+    io: Arc<Mutex<BytesIO>>,
     handshaker: HandshakeServer,
-    //complex_handshaker: ComplexHandshakeServer,
+
     packetizer: ChunkPacketizer,
     unpacketizer: ChunkUnpacketizer,
 
@@ -57,18 +57,17 @@ pub struct ServerSession {
 
     common: Common,
 
-    netio_data: BytesMut,
+    bytesio_data: BytesMut,
     need_process: bool,
 
     pub session_id: u64,
-    pub session_type: u8,
 
     connect_command_object: Option<HashMap<String, Amf0ValueType>>,
 }
 
 impl ServerSession {
     pub fn new(stream: TcpStream, event_producer: ChannelEventProducer, session_id: u64) -> Self {
-        let net_io = Arc::new(Mutex::new(NetworkIO::new(stream)));
+        let net_io = Arc::new(Mutex::new(BytesIO::new(stream)));
 
         Self {
             app_name: String::from(""),
@@ -76,7 +75,7 @@ impl ServerSession {
 
             io: Arc::clone(&net_io),
             handshaker: HandshakeServer::new(Arc::clone(&net_io)),
-            //complex_handshaker: ComplexHandshakeServer::new(Arc::clone(&net_io)),
+
             packetizer: ChunkPacketizer::new(Arc::clone(&net_io)),
             unpacketizer: ChunkUnpacketizer::new(),
 
@@ -85,9 +84,9 @@ impl ServerSession {
             common: Common::new(Arc::clone(&net_io), event_producer, SessionType::Server),
 
             session_id: session_id,
-            netio_data: BytesMut::new(),
+            bytesio_data: BytesMut::new(),
             need_process: false,
-            session_type: 0,
+
             connect_command_object: None,
         }
     }
@@ -111,8 +110,8 @@ impl ServerSession {
     }
 
     async fn handshake(&mut self) -> Result<(), SessionError> {
-        self.netio_data = self.io.lock().await.read().await?;
-        self.handshaker.extend_data(&self.netio_data[..]);
+        self.bytesio_data = self.io.lock().await.read().await?;
+        self.handshaker.extend_data(&self.bytesio_data[..]);
         self.handshaker.handshake().await?;
 
         match self.handshaker.state() {
@@ -134,10 +133,9 @@ impl ServerSession {
     }
 
     async fn read_parse_chunks(&mut self) -> Result<(), SessionError> {
-
         if !self.need_process {
-            self.netio_data = self.io.lock().await.read().await?;
-            self.unpacketizer.extend_data(&self.netio_data[..]);
+            self.bytesio_data = self.io.lock().await.read().await?;
+            self.unpacketizer.extend_data(&self.bytesio_data[..]);
         }
 
         self.need_process = false;
@@ -149,8 +147,7 @@ impl ServerSession {
                 match rv {
                     UnpackResult::Chunks(chunks) => {
                         for chunk_info in chunks.iter() {
-                            let mut msg = MessageParser::new(chunk_info.clone(), self.session_type)
-                                .parse()?;
+                            let mut msg = MessageParser::new(chunk_info.clone()).parse()?;
 
                             let msg_stream_id = chunk_info.message_header.msg_streamd_id;
                             let timestamp = chunk_info.message_header.timestamp;
@@ -226,7 +223,7 @@ impl ServerSession {
                 self.common.on_video_data(data, timestamp)?;
             }
             RtmpMessageData::AmfData { raw_data } => {
-                self.common.on_meta_data(raw_data)?;
+                self.common.on_meta_data(raw_data, timestamp)?;
             }
 
             _ => {}
@@ -261,14 +258,12 @@ impl ServerSession {
 
         match cmd_name.as_str() {
             "connect" => {
-                print!("connect .......");
                 self.on_connect(&transaction_id, &obj).await?;
             }
             "createStream" => {
                 self.on_create_stream(transaction_id).await?;
             }
             "deleteStream" => {
-                print!("deletestream....\n");
                 if others.len() > 0 {
                     let stream_id = match others.pop() {
                         Some(val) => match val {
@@ -277,17 +272,14 @@ impl ServerSession {
                         },
                         _ => 0.0,
                     };
-                    print!("deletestream....{}\n", stream_id);
                     self.on_delete_stream(transaction_id, &stream_id).await?;
                 }
             }
             "play" => {
-                self.session_type = config::SERVER_PULL;
                 self.unpacketizer.session_type = config::SERVER_PULL;
                 self.on_play(transaction_id, stream_id, others).await?;
             }
             "publish" => {
-                self.session_type = config::SERVER_PUSH;
                 self.unpacketizer.session_type = config::SERVER_PUSH;
                 self.on_publish(transaction_id, stream_id, others).await?;
             }
@@ -307,6 +299,11 @@ impl ServerSession {
         transaction_id: &f64,
         command_obj: &HashMap<String, Amf0ValueType>,
     ) -> Result<(), SessionError> {
+        log::info!(
+            "[ S<-C ] connect and the transaction id: {}",
+            transaction_id
+        );
+
         self.connect_command_object = Some(command_obj.clone());
         let mut control_message =
             ProtocolControlMessagesWriter::new(AsyncBytesWriter::new(self.io.clone()));
@@ -364,6 +361,11 @@ impl ServerSession {
     }
 
     pub async fn on_create_stream(&mut self, transaction_id: &f64) -> Result<(), SessionError> {
+        log::info!(
+            "[ S<-C ] create stream and the transaction id: {}",
+            transaction_id
+        );
+
         let mut netconnection = NetConnection::new(BytesWriter::new());
         let data = netconnection.create_stream_response(transaction_id, &define::STREAM_ID)?;
 
@@ -387,11 +389,17 @@ impl ServerSession {
         transaction_id: &f64,
         stream_id: &f64,
     ) -> Result<(), SessionError> {
+        log::info!(
+            "[ S<-C ] delete stream and the transaction id :{}, the stream id : {}",
+            transaction_id,
+            stream_id
+        );
+
         self.common
             .unpublish_to_channels(self.app_name.clone(), self.stream_name.clone())
             .await?;
 
-        let mut netstream = NetStreamWriter::new(BytesWriter::new(), Arc::clone(&self.io));
+        let mut netstream = NetStreamWriter::new(Arc::clone(&self.io));
         netstream
             .on_status(
                 transaction_id,
@@ -401,8 +409,6 @@ impl ServerSession {
             )
             .await?;
 
-        print!("stream id{}", stream_id);
-
         //self.unsubscribe_from_channels().await?;
 
         Ok(())
@@ -459,14 +465,17 @@ impl ServerSession {
             };
             break;
         }
-        print!("start {}", start.is_some());
-        print!("druation {}", duration.is_some());
-        print!("reset {}", reset.is_some());
+        log::info!(
+            "on_play, start: {}, duration: {}, reset: {}",
+            start.is_some(),
+            duration.is_some(),
+            reset.is_some()
+        );
 
         let mut event_messages = EventMessagesWriter::new(AsyncBytesWriter::new(self.io.clone()));
         event_messages.write_stream_begin(stream_id.clone()).await?;
 
-        let mut netstream = NetStreamWriter::new(BytesWriter::new(), Arc::clone(&self.io));
+        let mut netstream = NetStreamWriter::new(Arc::clone(&self.io));
         netstream
             .on_status(
                 transaction_id,
@@ -554,7 +563,7 @@ impl ServerSession {
         let mut event_messages = EventMessagesWriter::new(AsyncBytesWriter::new(self.io.clone()));
         event_messages.write_stream_begin(stream_id.clone()).await?;
 
-        let mut netstream = NetStreamWriter::new(BytesWriter::new(), Arc::clone(&self.io));
+        let mut netstream = NetStreamWriter::new(Arc::clone(&self.io));
         netstream
             .on_status(
                 transaction_id,
